# Changelog

## 0.1.0-alpha.4 (2025-05-07)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/phoebe-bird/phoebe-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### ⚠ BREAKING CHANGES

* **api:** upgrade SDK version to match new Typescript features

### Features

* **api:** upgrade SDK version to match new Typescript features ([83f1a29](https://github.com/phoebe-bird/phoebe-python/commit/83f1a295b0fbcda5d6914777ede4ecaddc8b602c))


### Bug Fixes

* **client:** only call .close() when needed ([#44](https://github.com/phoebe-bird/phoebe-python/issues/44)) ([484e3ae](https://github.com/phoebe-bird/phoebe-python/commit/484e3ae08c20157cbb81a235daf18aa53bca9eac))
* correctly handle deserialising `cls` fields ([#47](https://github.com/phoebe-bird/phoebe-python/issues/47)) ([56166e4](https://github.com/phoebe-bird/phoebe-python/commit/56166e431ac07307d0f7e4d25a5905511971fd5d))
* **tests:** make test_get_platform less flaky ([#50](https://github.com/phoebe-bird/phoebe-python/issues/50)) ([f7e04e6](https://github.com/phoebe-bird/phoebe-python/commit/f7e04e608f687f58ecbb621619deee5fc9a6f5c6))


### Chores

* add missing isclass check ([#42](https://github.com/phoebe-bird/phoebe-python/issues/42)) ([bb0e4dc](https://github.com/phoebe-bird/phoebe-python/commit/bb0e4dc7361b229ca908892d9e697b4849b58298))
* **internal:** add support for TypeAliasType ([#32](https://github.com/phoebe-bird/phoebe-python/issues/32)) ([74c00eb](https://github.com/phoebe-bird/phoebe-python/commit/74c00eb5f16b7d2c6cf91c210a7992132100c9ff))
* **internal:** avoid pytest-asyncio deprecation warning ([#51](https://github.com/phoebe-bird/phoebe-python/issues/51)) ([317cc73](https://github.com/phoebe-bird/phoebe-python/commit/317cc73943e8a3f16d3f3f5acc27f7c471c609ff))
* **internal:** bump httpx dependency ([#43](https://github.com/phoebe-bird/phoebe-python/issues/43)) ([7873621](https://github.com/phoebe-bird/phoebe-python/commit/78736215148315e67d9021f7252aa654cb4fe477))
* **internal:** bump pyright ([#31](https://github.com/phoebe-bird/phoebe-python/issues/31)) ([56fc9f6](https://github.com/phoebe-bird/phoebe-python/commit/56fc9f6d8e376ad59a310e5ee5477d1cef6e9755))
* **internal:** codegen related update ([#30](https://github.com/phoebe-bird/phoebe-python/issues/30)) ([ee29c81](https://github.com/phoebe-bird/phoebe-python/commit/ee29c817ae3bea67a36ca602e686a8e47ce01e43))
* **internal:** codegen related update ([#33](https://github.com/phoebe-bird/phoebe-python/issues/33)) ([e640d95](https://github.com/phoebe-bird/phoebe-python/commit/e640d9539985b248ef3b508c93343dd06b89f562))
* **internal:** codegen related update ([#34](https://github.com/phoebe-bird/phoebe-python/issues/34)) ([cccec95](https://github.com/phoebe-bird/phoebe-python/commit/cccec954d6dfdb94d4aee374f77b68b63c463db4))
* **internal:** codegen related update ([#35](https://github.com/phoebe-bird/phoebe-python/issues/35)) ([194b3b4](https://github.com/phoebe-bird/phoebe-python/commit/194b3b46be481eef30374a76cc4829acc17f036b))
* **internal:** codegen related update ([#36](https://github.com/phoebe-bird/phoebe-python/issues/36)) ([eb98a76](https://github.com/phoebe-bird/phoebe-python/commit/eb98a764095034b4bd8da2bde59340ca1f26d3f5))
* **internal:** codegen related update ([#41](https://github.com/phoebe-bird/phoebe-python/issues/41)) ([4287a29](https://github.com/phoebe-bird/phoebe-python/commit/4287a29895de379a38cc3ca5c506e2b579e3d05c))
* **internal:** codegen related update ([#46](https://github.com/phoebe-bird/phoebe-python/issues/46)) ([c437ad1](https://github.com/phoebe-bird/phoebe-python/commit/c437ad152220653915c1c4a49ef6e3c7f099fbcc))
* **internal:** codegen related update ([#48](https://github.com/phoebe-bird/phoebe-python/issues/48)) ([b96bf78](https://github.com/phoebe-bird/phoebe-python/commit/b96bf78ce97afb67421dc3f89ade6acc5c97b3e7))
* **internal:** codegen related update ([#52](https://github.com/phoebe-bird/phoebe-python/issues/52)) ([bdbf52a](https://github.com/phoebe-bird/phoebe-python/commit/bdbf52a0ad97c6afbb00178e7582b7594487da04))
* **internal:** fix some typos ([#40](https://github.com/phoebe-bird/phoebe-python/issues/40)) ([5fc44b6](https://github.com/phoebe-bird/phoebe-python/commit/5fc44b6ce5160daa48d6178f9b221f2a3214664a))
* **internal:** minor formatting changes ([#53](https://github.com/phoebe-bird/phoebe-python/issues/53)) ([65176ce](https://github.com/phoebe-bird/phoebe-python/commit/65176ce9ad9fb2068dd447297967dd6d866f6d55))
* **internal:** remove some duplicated imports ([#37](https://github.com/phoebe-bird/phoebe-python/issues/37)) ([eb66b37](https://github.com/phoebe-bird/phoebe-python/commit/eb66b377b34fb1a423aaf3b93ca578064601dfb1))
* **internal:** updated imports ([#38](https://github.com/phoebe-bird/phoebe-python/issues/38)) ([8d95da3](https://github.com/phoebe-bird/phoebe-python/commit/8d95da3455ca86cc236967c84ef261fe1047adb4))
* make the `Omit` type public ([#28](https://github.com/phoebe-bird/phoebe-python/issues/28)) ([3c28c9b](https://github.com/phoebe-bird/phoebe-python/commit/3c28c9b459c968964d3d57a179cc5a46e4cfc2fb))


### Documentation

* fix typos ([#45](https://github.com/phoebe-bird/phoebe-python/issues/45)) ([0a19122](https://github.com/phoebe-bird/phoebe-python/commit/0a191228b8969524f011c2a0dedeecd7d94154e3))
* **raw responses:** fix duplicate `the` ([#49](https://github.com/phoebe-bird/phoebe-python/issues/49)) ([b2244bb](https://github.com/phoebe-bird/phoebe-python/commit/b2244bb5675273bb3308fb7806a239456b8f4e46))
* **readme:** example snippet for client context manager ([#39](https://github.com/phoebe-bird/phoebe-python/issues/39)) ([ac62abe](https://github.com/phoebe-bird/phoebe-python/commit/ac62abeecbe5fc5204ff449a0dae14c8222fe743))

## 0.1.0-alpha.3 (2024-12-03)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/phoebe-bird/phoebe-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Bug Fixes

* **api:** get repo clean ([#14](https://github.com/phoebe-bird/phoebe-python/issues/14)) ([28470b8](https://github.com/phoebe-bird/phoebe-python/commit/28470b8579956fe39e92b6aa55a89d34fffd5ff4))
* **client:** compat with new httpx 0.28.0 release ([#25](https://github.com/phoebe-bird/phoebe-python/issues/25)) ([10748d0](https://github.com/phoebe-bird/phoebe-python/commit/10748d06f5154bfc9fd7bffb9a035aff449189b5))


### Chores

* **internal:** bump pyright ([#26](https://github.com/phoebe-bird/phoebe-python/issues/26)) ([b6362e9](https://github.com/phoebe-bird/phoebe-python/commit/b6362e9376aa5ceb958970682459e906727a4a45))
* **internal:** exclude mypy from running on tests ([#24](https://github.com/phoebe-bird/phoebe-python/issues/24)) ([2ab77ee](https://github.com/phoebe-bird/phoebe-python/commit/2ab77ee42f02eba645742b4eacab7b10581ead61))
* **internal:** fix compat model_dump method when warnings are passed ([#21](https://github.com/phoebe-bird/phoebe-python/issues/21)) ([7897301](https://github.com/phoebe-bird/phoebe-python/commit/7897301d160007df9e843c97f60481536bd07293))
* rebuild project due to codegen change ([#16](https://github.com/phoebe-bird/phoebe-python/issues/16)) ([19478a7](https://github.com/phoebe-bird/phoebe-python/commit/19478a7560434c8c2a1fa0b1680a6bbdd8307552))
* rebuild project due to codegen change ([#17](https://github.com/phoebe-bird/phoebe-python/issues/17)) ([698aecb](https://github.com/phoebe-bird/phoebe-python/commit/698aecbd81367cbfd331f0c78bbfc85f3cfcc012))
* rebuild project due to codegen change ([#18](https://github.com/phoebe-bird/phoebe-python/issues/18)) ([766d1a8](https://github.com/phoebe-bird/phoebe-python/commit/766d1a82564c074073e51bae85da72a069ede68f))
* rebuild project due to codegen change ([#19](https://github.com/phoebe-bird/phoebe-python/issues/19)) ([59ef073](https://github.com/phoebe-bird/phoebe-python/commit/59ef073731a6377866f9c6bc00e2fe53f4ce150e))
* rebuild project due to codegen change ([#20](https://github.com/phoebe-bird/phoebe-python/issues/20)) ([26413bd](https://github.com/phoebe-bird/phoebe-python/commit/26413bdf5fb60322d22a22cac4f0ac01d6029a0a))
* remove now unused `cached-property` dep ([#23](https://github.com/phoebe-bird/phoebe-python/issues/23)) ([5eba39b](https://github.com/phoebe-bird/phoebe-python/commit/5eba39bc3dab9ad10e8b82ed8c5cc875b688df42))


### Documentation

* add info log level to readme ([#22](https://github.com/phoebe-bird/phoebe-python/issues/22)) ([e37a2fc](https://github.com/phoebe-bird/phoebe-python/commit/e37a2fc11b65f4e975262a766f2d6d08545e14b5))

## 0.1.0-alpha.2 (2024-07-07)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/phoebe-bird/phoebe-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **docs:** update contact email ([#12](https://github.com/phoebe-bird/phoebe-python/issues/12)) ([1cadb56](https://github.com/phoebe-bird/phoebe-python/commit/1cadb564708531b50fc1d49a683b044e94708ab4))

## 0.1.0-alpha.1 (2024-07-07)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/phoebe-bird/phoebe-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** add docs to openapi spec ([#6](https://github.com/phoebe-bird/phoebe-python/issues/6)) ([48a914e](https://github.com/phoebe-bird/phoebe-python/commit/48a914ed6c19b308129b6ddb87b47600772b12f7))
* **api:** add python ([#1](https://github.com/phoebe-bird/phoebe-python/issues/1)) ([32d688d](https://github.com/phoebe-bird/phoebe-python/commit/32d688d87fe45ec05fe15306d48632eb246eaacf))
* **api:** fix adjacent region ([#5](https://github.com/phoebe-bird/phoebe-python/issues/5)) ([2eb594d](https://github.com/phoebe-bird/phoebe-python/commit/2eb594db27e90b97532c0fb52ebf12b93cf3e297))
* **api:** manual updates ([#3](https://github.com/phoebe-bird/phoebe-python/issues/3)) ([13a0146](https://github.com/phoebe-bird/phoebe-python/commit/13a0146de8696542ad5631252ff10851f85b06ba))


### Chores

* configure new SDK language ([0c39913](https://github.com/phoebe-bird/phoebe-python/commit/0c39913d143536aa1d7e096e79a74ad2ab8d973e))
* update SDK settings ([4174038](https://github.com/phoebe-bird/phoebe-python/commit/4174038355ba0b0c5ef9777709a00c5478925eaf))
* update SDK settings ([#4](https://github.com/phoebe-bird/phoebe-python/issues/4)) ([738803c](https://github.com/phoebe-bird/phoebe-python/commit/738803cff82bd54b44b8746f4b0fd5162c27ec1b))
* update SDK settings ([#7](https://github.com/phoebe-bird/phoebe-python/issues/7)) ([ee04119](https://github.com/phoebe-bird/phoebe-python/commit/ee041194307a44b0e723e7441a1e778e34495e5e))
